@@ -13,6 +13,7 @@ from .images import Images
 from .ui_config import UIConfig
 from .openshift import OpenShift
 from .user import User
+from jupyterhub_singleuser_profiles import sizes
 
 
 _LOGGER = logging.getLogger(__name__)
@@ -61,6 +62,13 @@ class SingleuserProfiles(object):
       for cm_name in profiles_config_maps:
         config_map_yaml = self.openshift.read_config_map(cm_name, key_name)
         if config_map_yaml:
+          if type(config_map_yaml) != dict:
+            message = '''
+            ConfigMap %s is incorrect - content must be object, not list.
+            Please review configuration documentation for the 
+            jupyterhub-singleuser-profiles library.
+            '''%cm_name
+            raise TypeError(message)
           self.gpu_types.extend(config_map_yaml.get("gpuTypes", []))
           self.sizes.extend(config_map_yaml.get("sizes", []))
           self.profiles.extend(config_map_yaml.get("profiles", [self.empty_profile()]))
@@ -109,7 +117,7 @@ class SingleuserProfiles(object):
       res = self.merge_profiles(res, p)
 
     if size:
-      s = Sizes(self.sizes)
+      s = Sizes(self.sizes, self.openshift)
       loaded_size = s.get_size(size)
       if loaded_size:
         res = self.merge_profiles(res, loaded_size)
@@ -149,23 +157,20 @@ class SingleuserProfiles(object):
       'segment_key': segment_key,
       'cluster_id': cluster_version.spec.get('clusterID')
     }
-    
 
   def get_sizes_form(self, username=None):
     if not self.profiles:
       self.load_profiles(username=username)
-    s = Sizes(self.sizes)
+    s = Sizes(self.sizes, self.openshift)
     return s.get_form(self.get_profile_by_name(_USER_CONFIG_PROFILE_NAME).get('last_selected_size'))
 
   def get_size(self, size):
-    s = Sizes(self.sizes)
+    s = Sizes(self.sizes, self.openshift)
     return s.get_size(size)
-    
-  def get_sizes(self):
-    return self.sizes
 
-  def get_image_info(self, image_name):
-    return self.images.get_info(image_name)
+  def get_sizes(self):
+    s = Sizes(self.sizes, self.openshift)
+    return s.sizes
 
   def get_gpu_types(self):
     return self.gpu_types
